pub enum Error {
Show 19 variants
InvalidPublicInputs,
InvalidCommitment,
WrongSessionId,
WrongDeployment,
WrongCookieVersion,
WrongCookieMode,
WrongPolicyId,
WrongServiceProvider,
WrongLicenseProvider,
WrongChallenge,
WrongAttributeData,
WrongRoot,
MissingAttributeOpening,
WrongAttributeOpening,
WrongLicenseProviderComm,
WrongAttributeDataComm,
WrongChallengeComm,
WrongSessionHash,
InvalidPublicKey,
}Expand description
All possible errors for Citadel
Variants
InvalidPublicInputs
The public input vector has the wrong length
InvalidCommitment
A public commitment point is malformed or not allowed
WrongSessionId
The session ID in the cookie does not match the session
WrongDeployment
The deployment metadata in the cookie does not match this verifier
WrongCookieVersion
The cookie object version does not match the selected policy
WrongCookieMode
The cookie mode does not match the selected policy
WrongPolicyId
The policy ID in the cookie does not match the selected policy
WrongServiceProvider
The cookie SP key does not match the selected policy
WrongLicenseProvider
The cookie LP key does not match the selected policy
WrongChallenge
The disclosed challenge does not match the selected policy
WrongAttributeData
The disclosed attribute data does not match the selected policy
WrongRoot
The session root does not satisfy the selected policy
MissingAttributeOpening
A required digest-style attribute opening is missing
WrongAttributeOpening
A supplied attribute opening does not match attr_data
WrongLicenseProviderComm
The commitment to the public key of the License Provider is incorrect
WrongAttributeDataComm
The commitment to the attribute data is incorrect
WrongChallengeComm
The commitment to the challenge is incorrect
WrongSessionHash
The result of the session hash is incorrect
InvalidPublicKey
A public key in the cookie or selected policy is malformed